# AISI S100-16

This module provides Julia functions that execute calculations defined in the American Iron and Steel Institute (AISI)  AISI S100-16 *North American Specification for the Design of Cold-Formed Steel Structural Members*.

Here are the functions that are currently available:

## Eq. F.3.2-1
```julia
Mnℓ = AISIS10016.f321(Mne, Mcrℓ, ASDorLRFD::Int8)
```
## Eq. F.4.1-1
```julia
Mnd = AISIS10016.f411(My, Mcrd, ASDorLRFD::Int8)
```
## Eq. H.4-2
```julia
ActionMx, ActionMy, ActionB, Interaction =  AISIS10016.h42(Mxbar, Mybar, Bbar, Maxℓo, Mayℓo, Ba)
```
## Eq. H.4.1-1
```julia
Bn = AISIS10016.h411(Cw, Fy, Wn, ASDorLRFD::Int8)
```
# Appendix 2

## Eq. 2.3.1.3-3
```julia
kϕfe = AISIS10016.app23133(E, Ixf, xof, hxf, Cwf, Ixyf, Iyf, L, G, Jf)
```
## Eq. 2.3.1.3-5
```julia
kϕfg = AISIS10016.app23135(L, Af, xof, hxf, Ixyf, Iyf, yof, Ixf)
```
## Eq. 2.3.3.3-1
```julia
Mcrd = AISIS10016.app23331(CorZ::Int8, t, ho, b, d, θc, E, μ, G, f1, f2, M1, M2, CurvatureSign::Int8, Lm, kϕ, Sf)
```
## Eq. 2.3.3.3-2
```julia
Fcrd = AISIS10016.app23332(β, kϕfe, kϕwe, kϕ, kϕfg, kϕwg)
```
## Eq. 2.3.3.3-3
```julia
β = AISIS10016.app23333(L, Lm, M1, M2, CurvatureSign::Int8)
```
## Eq. 2.3.3.3-4
```julia
L = AISIS10016.app23334(ho, μ, t, Ixf, xof, hxf, Cwf, Ixyf, Iyf, Lm)
```
## Eq. 2.3.3.3-5
```julia
kϕwe = AISIS10016.app23335(E,t,μ,ho,L)
```
## Eq. 2.3.3.3-6
```julia
kϕwg = AISIS10016.app23336(f1,f2,ho,t,L)
```
## Table 2.3.1.3-1
```julia
Af, Jf, Ixf, Iyf, Ixyf, Cwf, xof, hxf, hyf, yof = AISIS10016.table23131(CorZ::Int8,t,b,d,θ)
```

## Verification and testing log

### AISIS10016Test1.jl

Test Eq. 2.3.3.3-1, 8ZS2.25x070, no rotational spring, no moment gradient, Lm>>Lcrd
Predicted is about 9% lower than CUFSM, need to ask around about that

### AISIS10016Test2.jl

Test Eq. 2.3.3.3-1, 362S162-54, Mcrd, no springs, no moment gradient, Lm>>Lcrd
